:orphan:

.. _whats_new:

.. include:: whats_new/_contributors.rst

Release History
===============

Release notes for all treeple releases are linked in this page.

**Tip:** `Subscribe to treeple releases <https://libraries.io/pypi/treeple>`__
on libraries.io to be notified when new versions are released.

.. toctree::
    :maxdepth: 1

    Version 0.1 <whats_new/v0.1.rst>
    Version 0.2 <whats_new/v0.2.rst>
    Version 0.3 <whats_new/v0.3.rst>
    Version 0.4 <whats_new/v0.4.rst>
    Version 0.5 <whats_new/v0.5.rst>
    Version 0.6 <whats_new/v0.6.rst>
    Version 0.7 <whats_new/v0.7.rst>
    Version 0.8 <whats_new/v0.8.rst>
    Version 0.9 <whats_new/v0.9.rst>
    Version 0.10 (Unreleased) <whats_new/v0.10.rst>

